@@ -3,13 +3,13 @@
 /* The name of this package (not localized) */
 const PACKAGE_NAME = 'gnome-shell';
 /* The version of this package */
-const PACKAGE_VERSION = '3.10.0.1';
+const PACKAGE_VERSION = '3.10.1';
 /* 1 if gnome-bluetooth is available, 0 otherwise */
 const HAVE_BLUETOOTH = 1;
 /* gettext package */
 const GETTEXT_PACKAGE = 'gnome-shell';
 /* locale dir */
-const LOCALEDIR = '/usr/share/locale';
+const LOCALEDIR = '/home/fmuellner/opt/gnome/share/locale';
 /* other standard directories */
-const LIBEXECDIR = '/usr/libexec';
-const SYSCONFDIR = '/etc';
+const LIBEXECDIR = '/home/fmuellner/opt/gnome/libexec';
+const SYSCONFDIR = '/home/fmuellner/opt/gnome/etc';
