@@ -4,6 +4,7 @@ const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Lang = imports.lang;
 const Shell = imports.gi.Shell;
+const Signals = imports.signals;
 
 const Hash = imports.misc.hash;
 const Main = imports.ui.main;
@@ -41,28 +42,34 @@ const ScreencastService = new Lang.Class({
 
         this._recorders = new Hash.Map();
 
-        Main.sessionMode.connect('updated',
-                                 Lang.bind(this, this._sessionModeChanged));
+        Main.sessionMode.connect('updated', Lang.bind(this, this._sessionUpdated));
+    },
+
+    get isRecording() {
+        return this._recorders.size() > 0;
     },
 
     _ensureRecorderForSender: function(sender) {
         let recorder = this._recorders.get(sender);
         if (!recorder) {
-            recorder = new Shell.Recorder({ stage: global.stage });
+            recorder = new Shell.Recorder({ stage: global.stage,
+                                            screen: global.screen });
             recorder._watchNameId =
                 Gio.bus_watch_name(Gio.BusType.SESSION, sender, 0, null,
                                    Lang.bind(this, this._onNameVanished));
             this._recorders.set(sender, recorder);
+            this.emit('updated');
         }
         return recorder;
     },
 
-    _sessionModeChanged: function() {
+    _sessionUpdated: function() {
         if (Main.sessionMode.allowScreencast)
             return;
 
         for (let sender in this._recorders.keys())
             this._recorders.delete(sender);
+        this.emit('updated');
     },
 
     _onNameVanished: function(connection, name) {
@@ -77,6 +84,7 @@ const ScreencastService = new Lang.Class({
         Gio.bus_unwatch_name(recorder._watchNameId);
         recorder.close();
         this._recorders.delete(sender);
+        this.emit('updated');
 
         return true;
     },
@@ -105,7 +113,8 @@ const ScreencastService = new Lang.Class({
 
             recorder.set_file_template(fileTemplate);
             this._applyOptionalParameters(recorder, options);
-            returnValue = recorder.record();
+            let [success, fileName] = recorder.record();
+            returnValue = [success, fileName ? fileName : ''];
         }
 
         invocation.return_value(GLib.Variant.new('(bs)', returnValue));
@@ -125,7 +134,8 @@ const ScreencastService = new Lang.Class({
             recorder.set_file_template(fileTemplate);
             recorder.set_area(x, y, width, height);
             this._applyOptionalParameters(recorder, options);
-            returnValue = recorder.record();
+            let [success, fileName] = recorder.record();
+            returnValue = [success, fileName ? fileName : ''];
         }
 
         invocation.return_value(GLib.Variant.new('(bs)', returnValue));
@@ -136,3 +146,4 @@ const ScreencastService = new Lang.Class({
         invocation.return_value(GLib.Variant.new('(b)', [success]));
     }
 });
+Signals.addSignalMethods(ScreencastService.prototype);
